@@ -1,6 +1,7 @@
 import git
 import click
 
+from goBack.commands import goBack
 from init.commands import init
 from save.commands import save
 from ignore.commands import ignore
@@ -12,19 +13,20 @@ def cli(ctx):
     """ Git the easy way """
     #Check ctx was initialized
     ctx.ensure_object(dict)
-    
+
     if ctx.invoked_subcommand != 'init':
         try:
             repo = git.Repo(".", search_parent_directories=True)
             ctx.obj['REPO'] = repo
             #print( f"Location {repo.working_tree_dir}" )
             #print(f"Remote from init: {repo.remote('origin').url} ")
-        except Exception as e: 
+        except Exception as e:
             click.echo(e)
             #print("not git repo")
             exit()
 
 cli.add_command(init)
+cli.add_command(goBack)
 cli.add_command(save)
 cli.add_command(ignore)
 cli.add_command(compare)
