@@ -2,6 +2,7 @@ import git
 import click
 from PyInquirer import prompt
 from git import GitCommandError
+from .color_diff import color_diff
 
 @click.command()
 @click.pass_context
@@ -24,7 +25,8 @@ def compare(ctx,commit):
     full_list_of_commits = commits_full_list(repo)
     answer = prompt_for_commit_selection(full_list_of_commits, 'Select commit to compare')
     answer_hash = answer['commit'][:7]
-    click.echo(repo.git.diff(answer_hash))
+    diff_string = repo.git.diff(answer_hash)
+    click.echo('\n'.join(color_diff(diff_string.splitlines())))
 
 def prompt_for_commit_selection(list_of_commits, message):
     commit_page_index = 0
